#!/usr/bin/env python
# amaroK dcop interface

import os,pprint,re

class amaroKdcop:
   debug=0
   pp = pprint.PrettyPrinter()
   
   def getArtists (self):
      """return hash of all artists"""
      #print dict(self.execSql("select id||'##'||name from artist"))
      return dict(self.execSql("select id||'##'||name from artist"))

   def getArtistAlbums(self,artist):
      """Get all albums of an artist
      in: artist id
      return dict id:name"""
      return dict(self.execSql("select t.album||'##'||a.name from album a,tags t where t.artist=%s and t.album=a.id"%(artist)))

   def getAlbums(self):
      """return hash of all albums"""
      return dict(self.execSql("select id||'##'||name from album"))
      
   def getAlbumContent(self,id):
      """return album structure"""
      struct={}
      list = self.execSql("select track||'##'||title||'##'||length||'##'||url from tags where album=%s order by track"%(id,))
      struct['tracks']=list
      struct['artist']=self.execSql("select artist from tags t where t.album=%s LIMIT 1"%(id))[0][0]
      struct['cover']=self.getImage(id)
      struct['id']=id
      return struct
      
   def getImage(self,id):
      """return path to image of album"""
      list = self.execSql("select path from images, album a where images.album = a.name and a.id=%s"%(id,))
      # if no cover
      if list[0][0] == "":return ""
      # search for a name containing front
      p = re.compile(".*front.*",re.IGNORECASE)
      front = [l for l in list if p.match(l[0])]
      return len(front)>=1 and front[0][0] or list[0][0]

   def getSongs (self):
      """return list of all songs
      (title,length,url,album,artist)"""
      #print dict(self.execSql("select id||'##'||name from artist"))
      return self.execSql("select title||'##'||length||'##'||url||'##'||album||'##'||artist from tags")
      
   def getStats(self):
      """gather db stats in a dict"""
      stats={}
      stats['artists'] = self.execSql("select count(1) from artist")[0][0]
      stats['albums'] = self.execSql("select count(1) from album")[0][0]
      stats['songs'] = self.execSql("select count(1) from tags")[0][0]
      return stats
      
   def execSql (self,requete):
      """execute SQL request to amarok
         requete : string : the SQL request
         return lines in a list"""
      if self.debug: print requete
      ret=[]
      # exec the SQL request
      stdout = os.popen("dcop amarok collection query \"%s\""%requete)
      line = stdout.readline()
      while line:
         ret.append(line[:-1].split('##'))
         line = stdout.readline()
      #self.pp.pprint(ret)
      if self.debug: self.pp.pprint(ret)
      return ret

if __name__=="__main__":
   a = amaroKdcop()
   #print a.getArtists()
   #a.pp.pprint(a.getAlbums())
   #a.getAlbumContent(5)
   print a.getImage(2)
   
